@@ -35,7 +35,7 @@ RSpec.describe PDF::Core::ObjectStore do
     [10, 11, 12].each do |id|
       store.push(id, "some data #{id}")
     end
-    expect(store.map(&:identifier)[-3..-1]).to eq [10, 11, 12]
+    expect(store.map(&:identifier)[-3..]).to eq [10, 11, 12]
   end
 
   it 'accepts option to disabling PDF scaling in PDF clients' do
